@@ -25,9 +25,10 @@
  *
  *******************************************************************************/
 
- /* $Id: CTRLDialogue.cpp 343 2006-02-20 17:11:57Z common $ */
+ /* $Id: CTRLDialogue.cpp 1493 2007-12-13 21:29:01Z rui $ */
  
 #include <sys/types.h>
+#include <sys/param.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -114,7 +115,7 @@ ConsumeLevel CTRLDialogue::incomingData(Message *msg)
 //	logDebug("RX:\n%.*s\n",msg->getSize(),msg->getMsg());
 	if (m_Download == NULL && m_State < FTP_RETR)
 	{
-		logWarn("%s","broken ftp daemon \n");
+		logWarn("broken ftp daemon \n");
 		return CL_DROP;
 	}
 
@@ -206,11 +207,11 @@ ConsumeLevel CTRLDialogue::incomingData(Message *msg)
 			case FTP_RETR:
 				if (strncmp((char *)m_Buffer->getData() + iStart,"150 ",4) == 0)
 				{
-					logDebug("%s","RETR accepted\n");
+					logDebug("RETR accepted\n");
 				}else
 				if (strncmp((char *)m_Buffer->getData() + iStart,"226 ",4) == 0)
 				{
-					logDebug("%s","Transferr finished\n");
+					logDebug("Transferr finished\n");
 					sendQuit();
 					m_State = FTP_QUIT;
 				}
@@ -352,7 +353,7 @@ bool CTRLDialogue::parsePass(char *msg)
 {
 	if (strncmp(msg,"230 ",4) == 0)
 	{
-		logDebug("%s","Pass accepted, logged in \n");
+		logDebug("Pass accepted, logged in \n");
 		return true;
 	}else
 	{
@@ -366,7 +367,7 @@ bool CTRLDialogue::parsePass(char *msg)
 
 void CTRLDialogue::sendType()
 {
-	char *nmsg = "TYPE I\r\n";
+	const char *nmsg = "TYPE I\r\n";
 	m_Socket->doRespond(nmsg,strlen(nmsg));
 	logDebug("FTPSEND: '%s'\n",nmsg);
 }
@@ -375,7 +376,7 @@ bool CTRLDialogue::parseType(char *msg)
 {
 	if (strncmp(msg,"200 ",4) == 0)
 	{
-		logDebug("%s","Type accepted \n");
+		logDebug("Type accepted \n");
 		return true;
 	}else
 	{
@@ -387,7 +388,7 @@ bool CTRLDialogue::parseType(char *msg)
 
 void CTRLDialogue::sendPort()
 {
-	logDebug("%s","System ... \n");
+	logDebug("System ... \n");
 
 	uint32_t ip;
 	uint16_t minport;
@@ -425,6 +426,10 @@ void CTRLDialogue::sendPort()
 
 	for (uint16_t i =minport; i<maxport;i++)
 	{
+		/* workaround buggy PORT calculation in 'some' worm families */
+		if ( ((i >> 4) & 0xf) == 0 )
+			continue;
+
 		if ( (socket = g_Nepenthes->getSocketMgr()->bindTCPSocket(0,i,60,30)) != NULL )
 		{
 			if ( socket->getDialogst()->size() == 0 && socket->getFactories()->size() == 0 )
@@ -451,10 +456,17 @@ void CTRLDialogue::sendPort()
 	
 
 	asprintf(&nmsg,"PORT %d,%d,%d,%d,%d,%d\r\n",
+#if BYTE_ORDER == BIG_ENDIAN
+			(int32_t)(ip >> 24) & 0xff,
+			(int32_t)(ip >> 16) & 0xff,
+			(int32_t)(ip >> 8) & 0xff,
+			(int32_t)ip & 0xff,
+#else
 			(int32_t)ip & 0xff,
 			(int32_t)(ip >> 8) & 0xff,
 			(int32_t)(ip >> 16) & 0xff,
 			(int32_t)(ip >> 24) & 0xff,
+#endif
 			(int32_t)(port >> 8) & 0xff,
 			(int32_t)port & 0xff);
 	logDebug("FTPSEND: '%s'\n",nmsg);
@@ -467,7 +479,7 @@ bool CTRLDialogue::parsePort(char *msg)
 {
 	if (strncmp(msg,"200 ",4) == 0)
 	{
-		logDebug("%s","Port accepted\n");
+		logDebug("Port accepted\n");
 		return true;
 	}else
 	{
@@ -491,7 +503,7 @@ bool CTRLDialogue::parseRetr(char *msg)
 {
 	if (strncmp(msg,"150 ",4) == 0)
 	{
-		logDebug("%s","Retr accepted\n");
+		logDebug("Retr accepted\n");
 		return true;
 	}else
 	{
@@ -502,7 +514,7 @@ bool CTRLDialogue::parseRetr(char *msg)
 void CTRLDialogue::sendQuit()
 {
 	
-	char *nmsg = "QUIT\r\n";
+	const char *nmsg = "QUIT\r\n";
 	
 	logDebug("FTPSEND: '%s'\n",nmsg);
 	m_Socket->doRespond(nmsg,strlen(nmsg));
@@ -513,7 +525,7 @@ bool CTRLDialogue::parseQuit(char *msg)
 {
 	if (strncmp(msg,"221 ",4) == 0)
 	{
-		logDebug("%s","Quit accepted\n");
+		logDebug("Quit accepted\n");
 		return true;
 	}else
 	{
@@ -534,7 +546,7 @@ bool CTRLDialogue::parseCWD(char *msg)
 {
 	if (strncmp(msg,"250 ",4) == 0)
 	{
-		logDebug("%s","CWD accepted\n");
+		logDebug("CWD accepted\n");
 		return true;
 	}else
 	{
