@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: TFTPDownloadHandler.cpp 332 2006-02-20 09:28:45Z common $ */
+ /* $Id: TFTPDownloadHandler.cpp 550 2006-05-04 10:25:35Z common $ */
 
 
 #include <fcntl.h>
@@ -61,7 +61,7 @@ TFTPDownloadHandler::TFTPDownloadHandler(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "TFTP Download Module";
 	m_ModuleDescription = "provides a downloadhandler for tftp protocol";
-	m_ModuleRevision    = "$Rev: 332 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DownloadHandlerName ="tftp download handler";
@@ -84,7 +84,7 @@ bool TFTPDownloadHandler::Init()
 
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -94,7 +94,7 @@ bool TFTPDownloadHandler::Init()
 		m_MaxResends = m_Config->getValInt("download-tftp.max-resends");
     } catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
