@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: module-portwatch.cpp 321 2006-02-20 08:30:38Z common $ */
+ /* $Id: module-portwatch.cpp 550 2006-05-04 10:25:35Z common $ */
 
 #include <ctype.h>
 
@@ -79,7 +79,7 @@ WatchModule::WatchModule(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "module-portwatch";
 	m_ModuleDescription = "look for activity on new ports";
-	m_ModuleRevision    = "$Rev: 321 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "Watch Factory";
@@ -107,7 +107,7 @@ bool WatchModule::Init()
 	logPF();
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -119,7 +119,7 @@ bool WatchModule::Init()
 		timeout = m_Config->getValInt("module-portwatch.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
