@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: vuln-dcom.cpp 439 2006-03-27 18:11:55Z common $ */
+ /* $Id: vuln-dcom.cpp 550 2006-05-04 10:25:35Z common $ */
 
 
 #include <ctype.h>
@@ -55,7 +55,7 @@ DCOMVuln::DCOMVuln(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "vuln-dcom";
 	m_ModuleDescription = "emulate the dcom vuln";
-	m_ModuleRevision    = "$Rev: 439 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "dcom vuln Factory";
@@ -73,7 +73,7 @@ bool DCOMVuln::Init()
 	logPF();
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -85,7 +85,7 @@ bool DCOMVuln::Init()
 		timeout = m_Config->getValInt("vuln-dcom.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
