@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: vuln-msdtc.cpp 339 2006-02-20 09:45:09Z common $ */
+ /* $Id: vuln-msdtc.cpp 550 2006-05-04 10:25:35Z common $ */
 
 #include <ctype.h>
 
@@ -74,7 +74,7 @@ MSDTCVuln::MSDTCVuln(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "vuln-msdtc";
 	m_ModuleDescription = "modules provides msdtc emulation";
-	m_ModuleRevision    = "$Rev: 339 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "MSDTCDialogue Factory";
@@ -104,7 +104,7 @@ bool MSDTCVuln::Init()
 	logPF();
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -116,7 +116,7 @@ bool MSDTCVuln::Init()
 		timeout = m_Config->getValInt("vuln-msdtc.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
