@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: vuln-netbiosname.cpp 341 2006-02-20 09:51:00Z common $ */
+ /* $Id: vuln-netbiosname.cpp 550 2006-05-04 10:25:35Z common $ */
 
 #include <ctype.h>
 
@@ -85,7 +85,7 @@ NetbiosNameVuln::NetbiosNameVuln(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "vuln-netbiosname";
 	m_ModuleDescription = "provides Factory & dialogues for the netbios name resolution";
-	m_ModuleRevision    = "$Rev: 341 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "NetbiosName Factory";
@@ -121,7 +121,7 @@ bool NetbiosNameVuln::Init()
 		timeout = m_Config->getValInt("vuln-netbiosname.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
