@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: vuln-pnp.cpp 321 2006-02-20 08:30:38Z common $ */
+ /* $Id: vuln-pnp.cpp 550 2006-05-04 10:25:35Z common $ */
 
 #include <ctype.h>
 
@@ -77,7 +77,7 @@ PNPVuln::PNPVuln(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "vuln-pnp";
 	m_ModuleDescription = "modules provides pnp emulation";
-	m_ModuleRevision    = "$Rev: 321 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "PNPDialogue Factory";
@@ -107,7 +107,7 @@ bool PNPVuln::Init()
 	logPF();
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -119,7 +119,7 @@ bool PNPVuln::Init()
 		timeout = m_Config->getValInt("vuln-pnp.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
