@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: WINSDialogue.cpp 332 2006-02-20 09:28:45Z common $ */
+ /* $Id: WINSDialogue.cpp 836 2007-02-06 15:16:50Z common $ */
 
 #include "WINSDialogue.hpp"
 #include "Message.hpp"
@@ -41,6 +41,9 @@
 
 #include "Socket.hpp"
 
+#include "EventManager.hpp"
+#include "SocketEvent.hpp"
+
 #ifdef STDTAGS 
 #undef STDTAGS 
 #endif
@@ -123,5 +126,5 @@ void WINSDialogue::dump()
 {
 
 	logWarn("WINS unknown shellcode %i bytes State 0\n",m_Buffer->getSize());
-	g_Nepenthes->getUtilities()->hexdump(STDTAGS,(byte *) m_Buffer->getData(), m_Buffer->getSize());
+	HEXDUMP(m_Socket,(byte *) m_Buffer->getData(), m_Buffer->getSize());
 }
