@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: vuln-wins.cpp 439 2006-03-27 18:11:55Z common $ */
+ /* $Id: vuln-wins.cpp 550 2006-05-04 10:25:35Z common $ */
 
 #include <ctype.h>
 
@@ -57,7 +57,7 @@ WINSVuln::WINSVuln(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "vuln-wins";
 	m_ModuleDescription = "emulate the wins vuln";
-	m_ModuleRevision    = "$Rev: 439 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_DialogueFactoryName = "wins vuln Factory";
@@ -77,7 +77,7 @@ bool WINSVuln::Init()
 	logPF();
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -89,7 +89,7 @@ bool WINSVuln::Init()
 		timeout = m_Config->getValInt("vuln-wins.accepttimeout");
 	} catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
