@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: x-5.cpp 332 2006-02-20 09:28:45Z common $ */
+ /* $Id: x-5.cpp 1410 2007-10-12 13:07:23Z common $ */
 
 #include "x-5.hpp"
 #include "LogManager.hpp"
@@ -68,7 +68,7 @@ X5::X5(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "x-5";
 	m_ModuleDescription = "eXample Module 5 -eventhandler example-";
-	m_ModuleRevision    = "$Rev: 332 $";
+	m_ModuleRevision    = "$Rev: 1410 $";
 	m_Nepenthes = nepenthes;
 
 	m_EventHandlerName = "X5EventHandler";
@@ -106,7 +106,7 @@ bool X5::Init()
     m_Events.set(EV_SOCK_TCP_ACCEPT);
 	m_Events.set(EV_TIMEOUT);
 	REG_EVENT_HANDLER(this);
-	myevent = g_Nepenthes->getEventMgr()->registerEvent("EV_X5_TEST_EVENT");
+	myevent = g_Nepenthes->getEventMgr()->registerEvent((char*)"EV_X5_TEST_EVENT");
 	m_Events.set(myevent);
 	logInfo("My personal Event is %i\n",myevent);
 	return true;
@@ -149,7 +149,7 @@ uint32_t X5::handleEvent(Event *event)
 		break;
 
 	default:
-		logWarn("%s","this should not happen\n");
+		logWarn("this should not happen\n");
 	}
 	return 0;
 }
