@@ -1,4 +1,4 @@
-/* $Id: strsep.h,v 1.2 2004/05/27 20:09:29 vbrimhall Exp $ */
+/* $Id: Compatibility.hpp 446 2006-03-29 22:24:33Z common $ */
 
 #ifndef COMPABILITY_HPP
 #define COMPABILITY_HPP
@@ -11,5 +11,9 @@ extern char *strsep(char **stringp, const char *delim);
 extern int32_t stat(const char *file_name, struct _stat *buf);
 #endif
 
+#ifndef HAVE_STRNDUP
+extern char *strndup(char *str,int size);
+#endif 
+
 #endif 
 
